@@ -1,10 +1,10 @@
 import questionary
+import typer
 
 from .get_contents import AllPostGetter
 from .question import app
 from .utils import (console, get_choices, get_code, get_post_from_questionary,
                     handle_exception)
-import typer 
 
 
 @handle_exception
@@ -15,18 +15,22 @@ def get_post_from_question(titles: list):
 
 
 @app.command()
-def search_posts(pattern=typer.Argument(..., help='String pattern')):
+def search_posts(pattern=typer.Argument(..., help="String pattern")):
     """Search post based on the string pattern"""
     (
         titles_to_post,
         titles_to_code,
     ) = AllPostGetter().get_all_titles_with_links()
+
     relevant_titles = get_titles_based_on_pattern(
         pattern, titles_to_post.keys()
     )
+
     title = get_post_from_questionary(get_choices(relevant_titles))
     post = titles_to_post[title]
-    console.print(f"Here is the link: [bold cyan]{post}[/bold cyan] :boom:")
+    console.print(
+        f"Here is the link to the post: [bold cyan]{post}[/bold cyan] :boom:"
+    )
     get_code(titles_to_code[title])
 
 
@@ -34,6 +38,7 @@ def is_relevant_title(pattern: str, title: str):
     return pattern.lower() in title.lower()
 
 
+@handle_exception
 def get_titles_based_on_pattern(pattern: str, titles: list):
     relevant_titles = [
         title for title in titles if is_relevant_title(pattern, title)
